puppy_rct: More puppy therapy data

puppy_rctR Documentation

More puppy therapy data

Description

A dataset from Field, A. P. (2026). Discovering statistics using R and RStudio (2nd ed.). London: Sage.

Usage

puppy_rct

Format

A tibble with 30 rows and 4 variables.

Details

The researchers who conducted the puppy therapy study in puppies suddenly realized that a participant's baseline happiness would affect their happiness scores after puppy therapy and wanted to adjust for this revelation. Therefore, they repeated the study on different participants, but measured happiness at baseline (pre-treatment) as well as post-therapy. The tibble contains the following variables:

  • id: Participant id

  • dose: Treatment group to which the participant was randomly assigned (No puppies (control), 15 minutes of puppy therapy, 30 minutes of puppy therapy)

  • pre_happy: Self-reported happiness from 0 (as unhappy as I can possibly imagine being) to 10 (as happy as I can possibly imagine being) before puppy therapy began.

  • post_happy: Self-reported happiness from 0 (as unhappy as I can possibly imagine being) to 10 (as happy as I can possibly imagine being) after puppy therapy concluded.

www.discovr.rocks/csv/puppy_rct.csv


discovr documentation built on Feb. 5, 2026, 5:07 p.m.